.. AMQPCTL documentation master file, created by

AMQP Command Line Utility
=========================

Contents:

.. toctree::
   :maxdepth: 2

   installation.rst
   usage.rst
   implementation.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

